/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: BUSL-1.1
 */

import CertSerializer from './certificate/base';

export default class PkiCertificateSerializer extends CertSerializer {}
